==> cloudfoundry-client-5.10.0.RELEASE-sources.jar: org/cloudfoundry/client/v3/_Lifecycle.java <==
/*
 * Copyright 2013-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v3;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import org.immutables.value.Value;

/**
 * The lifecycle type
 */
@JsonDeserialize
@Value.Immutable
abstract class _Lifecycle {

    /**
     * The data for the lifecycle
     */
    @JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXTERNAL_PROPERTY, property = "type")
    @JsonSubTypes({
        @JsonSubTypes.Type(name = "buildpack", value = BuildpackData.class),
        @JsonSubTypes.Type(name = "docker", value = DockerData.class),
        @JsonSubTypes.Type(name = "kpack", value = KpackData.class)
    })
    @JsonProperty("data")
    abstract LifecycleData getData();

    /**
     * The type
     */
    @JsonProperty("type")
    abstract LifecycleType getType();

}

==> cloudfoundry-client-5.14.0.RELEASE-sources.jar: org/cloudfoundry/client/v3/_Lifecycle.java <==
/*
 * Copyright 2013-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v3;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonSubTypes;
import com.fasterxml.jackson.annotation.JsonTypeInfo;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import org.immutables.value.Value;

/**
 * The lifecycle type
 */
@JsonDeserialize
@Value.Immutable
abstract class _Lifecycle {

    /**
     * The data for the lifecycle
     */
    @JsonTypeInfo(use = JsonTypeInfo.Id.NAME, include = JsonTypeInfo.As.EXTERNAL_PROPERTY, property = "type")
    @JsonSubTypes({
        @JsonSubTypes.Type(name = "buildpack", value = BuildpackData.class),
        @JsonSubTypes.Type(name = "docker", value = DockerData.class),
        @JsonSubTypes.Type(name = "kpack", value = KpackData.class),
        @JsonSubTypes.Type(name = "cnb", value = CnbData.class)
    })
    @JsonProperty("data")
    abstract LifecycleData getData();

    /**
     * The type
     */
    @JsonProperty("type")
    abstract LifecycleType getType();

}
